@@ -1,4 +1,3 @@
-# coding=utf-8
 # -*- coding:utf-8 -*-
 
 from ..util import client, oss_client, formater, list2table, result_cache, dag, util
@@ -241,7 +240,7 @@ def getTaskDetail(jobId, taskName):
         arr = formater.format_date_in_arr(insts['Items'], [ 'StartTime', 'EndTime'])
         list2table.print_table(arr, ['InstanceId',('State', 'State', formater.get_job_state)
                                      , ('Progress','Progress',lambda s:'%s%%' % s), 'RetryCount'
-            ,'StartTime','EndTime'],show_no=False)
+            ,'StartTime','EndTime','Elapsed'],show_no=False)
 
     print(white('\n  type "%s j <jobId|No.> <taskName|No.> <instanceId>" to show instance detail\n' % CMD))
 
@@ -256,7 +255,7 @@ def getInstanceDetail(jobId, taskName, instanceId):
     arr = formater.format_date_in_arr([formater.to_dict(ins)], ['CreationTime', 'StartTime', 'EndTime'])
 
     print('%s' % bold(magenta('Instance:')))
-    list2table.print_table(arr, cols=['InstanceId',('State', 'State', formater.get_job_state), ('Progress','Progress',lambda s:'%s%%' % s), 'RetryCount','StartTime','EndTime'  ], show_no=False)
+    list2table.print_table(arr, cols=['InstanceId',('State', 'State', formater.get_job_state), ('Progress','Progress',lambda s:'%s%%' % s), 'RetryCount','StartTime','EndTime','Elapsed' ], show_no=False)
 
     stdout_path = formater.fix_log_path(ins.StdoutRedirectPath,jobId,taskName, instanceId, 'stdout')
     stderr_path = formater.fix_log_path(ins.StderrRedirectPath,jobId,taskName, instanceId, 'stderr')
