@@ -5,7 +5,6 @@ from .action import login, config,info, cluster, job, cluster_create, cluster_de
 
 import os
 from . import const,i18n_util,cli_project,cli_oss
-from .util import config as Cfg
 
 COMMAND = const.COMMAND
 CMD = const.CMD
@@ -52,11 +51,14 @@ cmd_config = Command('config', alias=['me','set'], description=MSG['config']['de
 
   Examples:
      1. %s config     # show configurations
-     2. %s config -r cn-qingdao -o oss://my-bucket/bcscli/ -l zh_CN ''' % (COMMAND, CMD, CMD),
+     2. %s set -r cn-qingdao -o oss://my-bucket/bcscli/ -l zh_CN
+     3. %s set -i %s -t %s ''' % (COMMAND, CMD, CMD,CMD ,IMG_ID, INS_TYPE),
                      func=config.all)
 cmd_config.option('-r,--region [region]', MSG['config']['option']['region'])
 cmd_config.option('-o,--osspath [osspath]', MSG['config']['option']['osspath'] )
 cmd_config.option('-l,--locale [locale]', MSG['config']['option']['locale'])
+cmd_config.option('-i,--image [imageId]', MSG['config']['option']['image'])
+cmd_config.option('-t,--type [instanceType]', MSG['config']['option']['type'])
 program.action(cmd_config)
 
 # info
@@ -304,6 +306,7 @@ def cmd_project_print_help():
 
 # project
 cmd_project = Command('project', alias=['p'],
+                      visible=False,
                          description=MSG['project']['description'],
                          func=cmd_project_print_help , spliter='\n    -----%s----------------' % blue('sub command'))
 program.action(cmd_project)
@@ -347,8 +350,9 @@ cmd_submit_job = Command('submit', alias=['sub'],
       2. %s sub "echo 'hello'" -c img=%s                                         # use auto cluster
       3. %s sub "python main.py arg1 arg2" job_name -c cls-xxxxx -p ./my_program/         # set job name, use cluster id, pack a folder and upload
       4. %s sub "python /home/admin/test/main.py" -m oss://bucket/a/b/:/home/admin/test/  # mount an oss path to a local path
-      5. %s sub "python test.py" -p test.py --docker myubuntu@oss://bucket/dockers/       # run in docker container''' % (
-                         COMMAND, CMD, CMD, IMG_ID, CMD, CMD, CMD),
+      5. %s sub "python test.py" -p test.py --docker myubuntu@oss://bucket/dockers/       # run in docker container
+      6. %s sub --file job.cfg                    # submit a job from job.cfg''' % (
+                         COMMAND, CMD, CMD, IMG_ID, CMD, CMD, CMD, CMD),
                          spliter='\n    -----%s----------------' % blue('quick cmd'),
                          func=job_submit.submit)
 
@@ -390,7 +394,6 @@ program.action(cmd_check)
 ##############################################
 
 
-
 def main():
     if os.getenv('DEBUG'):
         program.parse()
