@@ -6,7 +6,7 @@ CMD = 'bcs'
 
 LOCALE_SUPPORTED = ['en', 'zh', 'zh_CN']
 
-VERSION = '1.1.21'
+VERSION = '1.2.0'
 
 
 IT = {
@@ -27,20 +27,32 @@ IT = {
 }
 
 IMG = {
-    'cn-qingdao': 'm-28y1qjeg1'
+    'cn-qingdao': {
+        'data': [],
+        'default': 'm-282q1y6ld'
+    }
 }
 
 
 from .util import config
 
-try:
-    REGION = config.getRegion()
-    INS_TYPE = IT[REGION]['default']
-    IMG_ID = IMG[REGION]
-except:
-    INS_TYPE='ecs.s3.large'
-    IMG_ID = IMG['cn-qingdao']
 
+configObj = config.getConfigs(config.COMMON)
+region = configObj.get('region')
+if region:
+    REGION = region
+
+
+
+try:
+    IT_DATA = IT[REGION]['data']
+    INS_TYPE = configObj.get('defaulttype') or IT[REGION]['default']
+    IMG_ID = configObj.get('defaultimage') or IMG[REGION]['default']
+
+except Exception as e:
+    INS_TYPE='ecs.s3.large'
+    IT_DATA = IT['cn-qingdao']['data']
+    IMG_ID = IMG['cn-qingdao']['default']
 
 
 
