@@ -6,15 +6,17 @@ from batchcompute.utils import set_log_level
 set_log_level("ERROR")
 
 def _get_endpoint(region):
-    return 'batchcompute.%s.aliyuncs.com' % region
+    domain = 'batchcompute.%s.aliyuncs.com' % region
+    Client.register_region(region, domain)
+    return domain
 
 
 def _get_client(opt=None):
-    opt = opt or getConfigs(COMMON, ['region','endpoint', 'accesskeyid','accesskeysecret'])
+    opt = opt or getConfigs(COMMON, ['region', 'accesskeyid','accesskeysecret'])
     if not opt or not opt.get('accesskeyid'):
         raise Exception('You need to login first')
 
-    return Client(opt.get('endpoint') or  _get_endpoint(opt.get('region')),
+    return Client(_get_endpoint(opt.get('region')),
         opt.get('accesskeyid'), opt.get('accesskeysecret'))
 
 def check_client(opt):
