@@ -5,7 +5,6 @@ except:
     import configparser as ConfigParser
 
 import os
-from .. import const
 
 cf = ConfigParser.ConfigParser()
 
@@ -17,7 +16,8 @@ cfg_path = os.path.join(cfg_dir, 'cliconfig')
 
 COMMON = 'common'
 
-def getConfigs(section, keys=['region','accesskeyid','accesskeysecret','osspath','locale']):
+def getConfigs(section, keys=['region','accesskeyid','accesskeysecret','osspath','locale','god',
+                              'defaultimage','defaulttype']):
     '''
     section: currently support 'common' only
     keys: array, example: ['region','accesskeyid']
@@ -71,7 +71,20 @@ def removeConfig(section, key):
 def get_oss_path():
     pre_oss_path = getConfigs(COMMON,['osspath']).get('osspath')
     if not pre_oss_path:
-        raise Exception('osspath is unset, type: "%s config -h" for more help' % const.CMD)
+        raise Exception('osspath is unset, type: "bcs config -h" for more help')
 
     pre_oss_path = '%s/' % pre_oss_path.rstrip('/')
     return pre_oss_path
+
+def isGod():
+    return getConfigs(COMMON, ['god']).get('god')
+
+def getRegion():
+    region= getConfigs(COMMON, ['region']).get('region')
+    if region:
+        return region
+    else:
+        raise Exception('you need to login first')
+
+
+
