@@ -124,33 +124,33 @@ def from_now(dt, detail=False):
     sec = time.mktime(dt.timetuple())
 
     sec = (nt-sec)
+    return from_sec(sec)+' ago'
 
-    t=[]
-    if sec > 24*3600:
-        d = int(sec/(24*3600))
-        sec = sec - d*24*3600
-        t.append('%sD'%d)
+def from_sec(sec, detail=False):
+    t = []
+    if sec > 24 * 3600:
+        d = int(sec / (24 * 3600))
+        sec = sec - d * 24 * 3600
+        t.append('%sD' % d)
         if not detail:
-            return ''.join(t)+' ago'
+            return ''.join(t)
     if sec > 3600:
-        h = int(sec/3600)
-        sec = sec - h*3600
-        t.append('%sH'%h)
+        h = int(sec / 3600)
+        sec = sec - h * 3600
+        t.append('%sH' % h)
         if not detail:
-            return ''.join(t)+' ago'
+            return ''.join(t)
     if sec > 60:
-        m = int(sec/60)
-        sec = sec - m*60
-        t.append('%sm'%m)
+        m = int(sec / 60)
+        sec = sec - m * 60
+        t.append('%sm' % m)
         if not detail:
-            return ''.join(t)+' ago'
+            return ''.join(t)
     if sec > 0:
-        t.append('%ss'% int(sec))
+        t.append('%ss' % int(sec))
         if not detail:
-            return ''.join(t)+' ago'
-    return ''.join(t)+' ago'
-
-
+            return ''.join(t)
+    return ''.join(t)
 
 def to_dict(item):
     m = {}
@@ -176,7 +176,8 @@ def fix_log_path(s, jobId,taskName, instanceId, logType):
 
 def calc_elapse(start, end):
     if start and end:
-        return '%ds' % int(time.mktime(end.timetuple()) - time.mktime(start.timetuple()))
+        sec = int(time.mktime(end.timetuple()) - time.mktime(start.timetuple()))
+        return from_sec(sec, detail=True)
     else:
         return ''
 
